@@ -15,8 +15,8 @@
 
    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
-   Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
-   02111-1307, USA. */
+   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301
+   USA. */
 
 #include <stdlib.h>
 #include <ctype.h>
@@ -374,9 +374,9 @@ sfm_read_dictionary (struct file_handle * h, struct sfm_read_info * inf)
 	  {
 	    struct
 	      {
-		R_int32 subtype P;
-		R_int32 size P;
-		R_int32 count P;
+		R_int32 subtype;
+		R_int32 size;
+		R_int32 count;
 	      }
 	    data;
 
